<?php

namespace Drupal\xray_audit_insight\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class for settings form.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The module settings.
   */
  const MODULE_SETTINGS = 'xray_audit_insight.settings';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::MODULE_SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'xray_audit_insight.settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::MODULE_SETTINGS);

    $form['insight_switch'] = [
      '#type' => 'container',
    ];
    $form['insight_switch']['title'] = [
      '#type' => 'html_tag',
      '#tag' => 'h4',
      '#value' => $this->t('Exclusion of insights'),
    ];
    $form['insight_switch']['description'] = [
      '#type' => 'html_tag',
      '#tag' => 'p',
      '#value' => $this->t('Select the insights that you do not want to be displayed in the Status Report.'),
    ];

    $insights = $this->getInsights();
    foreach ($insights as $insight) {
      $form['insight_switch'][$insight['id']] = [
        '#type' => 'checkbox',
        '#title' => $insight['label'] ?? '',
        '#default_value' => $config->get($insight['id']) ?? FALSE,
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $config_object = $this->config(static::MODULE_SETTINGS);
    $insights = $this->getInsights();

    foreach ($insights as $insight) {
      $config_object->set($insight['id'], (bool) $form_state->getValue($insight['id']));
    }

    $config_object->save();
  }

  /**
   * Get the insights.
   *
   * @return array
   *   The insights.
   */
  protected function getInsights(): array {
    $insights = [];

    $insights['bundle_not_used'] = [
      'label' => $this->t('Entities bundles not used.'),
    ];

    $insights['modules_not_enabled'] = [
      'label' => $this->t('Modules not enabled.'),
    ];

    foreach ($insights as $plugin_id => &$insight) {
      $insight['id'] = 'excluded_' . $plugin_id;
    }

    return $insights;
  }

}
